@@ -249,6 +249,13 @@ class ArpSpoof:
 
 class NetAck:
 
+    import Code_Injector
+    import Sniffer
+    import FakeDownload
+    import NetworkScanner
+    import MAC
+    import DNSSpoof
+    import ArpSpoof
     def arpspoof(self, target_ip, gateway_ip):
         arp = ArpSpoof()
         arp.start(target_ip, gateway_ip)
